pub struct ClientCounts {
pub memory_clients: Vec<u16>,
pub native_count: usize,
pub wasm_wt_count: usize,
pub wasm_ws_count: usize,
}Available on crate feature
server only.Expand description
The number of clients that will connect to a server with different connection types.
Used by [setup_combo_renet2_server] to set max-client limits and determine what server sockets are required.
Note that we assume clients will not change connection type throughout a game. If you want to allow clients
to change connection type, then set each count below equal to the total number of clients.
Fields
memory_clients: Vec<u16>The ids of in-memory clients that will connect.
Ids must be in the range [0, u16::MAX).
native_count: usizeThe number of native clients that will connect.
wasm_wt_count: usizeThe number of WASM webtransport clients that will connect.
wasm_ws_count: usizeThe number of WASM websocket clients that will connect.
Implementations
Sourceimpl ClientCounts
impl ClientCounts